@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,7 +17,7 @@
 mod builder;
 mod error;
 mod profile;
-#[cfg(feature = "rest-api")]
+#[cfg(feature = "rest-api-actix-web-1")]
 pub(crate) mod rest_api;
 pub mod store;
 mod subject;
@@ -230,7 +230,7 @@ fn new_basic_client(
                 .map_err(|err| InvalidArgumentError::new("token_url".into(), err.to_string()))?,
         ),
     )
-    .set_redirect_url(
+    .set_redirect_uri(
         RedirectUrl::new(redirect_url)
             .map_err(|err| InvalidArgumentError::new("redirect_url".into(), err.to_string()))?,
     ))
